#!/bin/bash
#
# Checks to see whether the server should update during
# the regularly scheduled updates. This script should be run daily
# to check for updates
#
# Calvin Smith <casmith@redhat.com>
#
############################
#
# Currently decided upon schedule based on week of month
# (tuesday = 2 where sunday = 0 )
# DEV= 1st tuesday of month
# TEST=2nd tuesday of month
# PROD=3rd tuesday of month
# LAB=every friday of month
# Change these values to alter schedule
#
DEBUG=
# EMAIL="csvd.csa.teams.list@census.gov,smab.teams.2@census.gov"
EMAIL="csvd.csa.teams.list@census.gov"
# EMAIL="calvin.g.smith@census.gov"
LOGFILE=/var/log/auto-up2date.log
echo "Started auto-up2date script" > $LOGFILE
date >> $LOGFILE

DEV_CHAN='CSVD-DEV'
DEV_DOW=2
DEV_WOM=1

TEST_CHAN='CSVD-TEST'
TEST_DOW=2 
TEST_WOM=2

PROD_CHAN='CSVD-PROD'
PROD_DOW=2
PROD_WOM=3

LAB_CHAN='CSVD-LAB'
LAB_DOW=5

SKIP_FILE="/etc/census/up2date/skip"
#
# Gets week of month
# 
function getweekofmonth() {
  DOM=`date +%e`
  WEEKOFMONTH=1
  while [ $DOM -gt 6 ] ;
  do
    WEEKOFMONTH=`expr $WEEKOFMONTH + 1`
    DOM=`expr $DOM - 7`
  done
  return $WEEKOFMONTH
}
#
# Updates servers based on week of month
#
function update_server() {
  _CLASS=$1
  _CHAN=$2
  _DOW=$3
  _WOM=$4
  echo "Considering $_CLASS server" >> $LOGFILE
  echo $CFG_CHANNELS | grep -q $_CHAN
  if [ $? -eq 0 ] ; then
    cat<<EOF>>$LOGFILE
- Checking on   Day of week: $DOW vs ${_CLASS}   day of week: $_DOW
- Checking on Week of Month: $WOM vs ${_CLASS} week of month: ${_WOM:-"unset"}
EOF
    if [ $DOW -eq $_DOW ] && ( [  "x$_WOM" = "x" ] || [  $_WOM -eq $WOM ] ) ; then
      if [ -f $SKIP_FILE ] ; then
        rm $SKIP_FILE
	echo "Removed skip file $SKIP_FILE" >> $LOGFILE
      else
        if [ $DEBUG ] ; then 
          echo "- Would update $_CLASS server"
        else
          up2date -u >> $LOGFILE 2>&1
	  if [ $? -ne 0 ] ; then 
	    echo "up2date failed!"
	    SUB="auto-up2date: $(hostname) failed up2date! message body is log file"
	    cat $LOGFILE | mailx -s "$SUB" $EMAIL 
	  fi
        fi
      fi
    fi
  fi
}
#######################################################
#
# Main LOOP
# 
CFG_CHANNELS=`rhncfg-client channels`

getweekofmonth
WOM=$?
DOW=`date +'%w'`

update_server "TEST" $TEST_CHAN $TEST_DOW $TEST_WOM
update_server "DEV" $DEV_CHAN $DEV_DOW $DEV_WOM
update_server "PROD" $PROD_CHAN $PROD_DOW $PROD_WOM
update_server "LAB" $LAB_CHAN $LAB_DOW
